from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ScalarConfig(AppConfig):
    name = "django_scalar"
    verbose_name = _("Django Scalar")

    def ready(self):
        # load/register something important, like signals
        pass



from django.shortcuts import render


def scalar_viewer(request):
    openapi_url = "/api/schema/"
    title = "Scalar Api Reference"
    scalar_js_url = "https://cdn.jsdelivr.net/npm/@scalar/api-reference"
    scalar_proxy_url = ""
    scalar_favicon_url = "/static/favicon.ico"
    return render(request, "django_scalar/scalar.html", locals())



from django.urls import path
from drf_spectacular.views import SpectacularAPIView, SpectacularSwaggerView

from .scalar import scalar_viewer


app_name = "django_scalar"

urlpatterns = [
    path("api/schema/", SpectacularAPIView.as_view(), name="schema"), # im using drf_spectacular and is the one that i tested with. ps: this endpoint need to be the same from {openapi_url}
    path(
        "api/schema/swagger-ui/",
        SpectacularSwaggerView.as_view(url_name="schema"),
        name="swagger-ui",
    ), # is not needed but if you want, you can keep it.
    path("api/docs/", scalar_viewer, name="docs"), # scalar view.
]
